<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
version="1.0">

<!-- Localised settings for numbers -->
<xsl:decimal-format name="en" decimal-separator="." grouping-separator="," NaN="&#60;Null&#62;"/>
<xsl:decimal-format name="de" decimal-separator="," grouping-separator="." NaN="&#60;Null&#62;"/>

<!-- Reference to the external document with all data -->
<xsl:variable name="EPANET" select="document('EPANETModel.xml')"/>

<!-- Index on results for faster lookup -->
<xsl:key name="ResultKey" match="Group[@Name='mw_RESLink']/Rows/R" use="@MUID"/>

<xsl:template match="/">
	<html>
		<head>
			<title>Ergebnisse in Rohren</title>
			<!-- Reference to the external stripes script -->
			<script src="stripes.js" type="text/javascript">
			</script>
		</head>

		<!-- Reference to the external style sheet -->
		<link rel="stylesheet" type="text/css"  href="default.css"/>

		<!-- Colour for uneven rows and for even rows -->
		<body onload="stripe('tabelle', '#ffffff', '#96c3e3')">

			<div id="firmablock">
				<xsl:for-each select="document('Unternehmen.xml')/name/zeile">
					<p>
						<xsl:value-of select="."/>
					</p>
				</xsl:for-each>
			</div>
			
			<div id="projektblock">
				<xsl:for-each select="document('Projekt.xml')/titel/zeile">
					<p>
						<xsl:value-of select="."/>
					</p>
				</xsl:for-each>
			</div>
			
			<h1>Ergebnisse in Rohren</h1>

			<table id="tabelle" border="0" cellpadding="0" cellspacing="0" summary="">

			<!-- Custom text, e.g. company name, project name
			     In order to make custom text visible, remove: display:none  -->
			<caption style="text-align:left; display:none;"></caption>

			<colgroup>
				<!--  Column width and column alignment -->
				<col width="75px" />							<!-- Rohr ID -->
				<col width="75px"/>		<!-- Von Knoten -->
				<col width="75px"/>		<!-- Nach Knoten -->
				<col width="75px" style="text-align: right;"/>	<!-- Durchmesser -->
				<col width="75px" style="text-align: right;"/>	<!-- Lnge -->
				<col width="75px" style="text-align: right;"/>	<!-- Durchfluss max -->
				<col width="75px" style="text-align: right;"/>	<!-- Geschw. max -->
				<col width="75px" style="text-align: right;"/>	<!-- Geflle max -->
			</colgroup>

			<thead>
				<tr>
					<!-- Column headers with units -->
					<xsl:for-each select="$EPANET/mu">
					<th>
						Rohr ID<br />
					</th>
					<th>
						Von<br />
						Knoten
					</th>
					<th>
						Nach<br />
						Knoten
					</th>
					<th>
						Durch-<br />
						messer<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Group[@Name='mw_Pipe']/Metadata/Field[@Name='Diameter']/@Unit"/></xsl:call-template>
					</th>
					<th>
						Lnge<br />
						<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Group[@Name='mw_Pipe']/Metadata/Field[@Name='L']/@Unit"/></xsl:call-template>
					</th>
					<th>
						Durch-<br />
						fluss<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Group[@Name='mw_RESLink']/Metadata/Field[@Name='Flow_Max']/@Unit"/></xsl:call-template>
					</th>
					<th>
						Geschw<br />
						<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Group[@Name='mw_RESLink']/Metadata/Field[@Name='Velocity_Max']/@Unit"/></xsl:call-template>
					</th>
					<th>
						Geflle<br />
						<br />
						<!-- <xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Group[@Name='mw_RESLink']/Metadata/Field[@Name='Headloss1000_Max']/@Unit"/></xsl:call-template> -->
					</th>

					</xsl:for-each>
				</tr>
			</thead>

			<xsl:for-each select="$EPANET/mu/Group[@Name='mw_Pipe']/Rows/R">
				<xsl:sort select="@MUID"/>
				<tr>
					<!-- Data within each row including number format -->
					<td><xsl:value-of select="@MUID"/></td>
					<td><xsl:value-of select="@_FromNodeID"/></td>
					<td><xsl:value-of select="@_ToNodeID"/></td>
					<td><xsl:value-of select="format-number(@Diameter,'#.##0','de')"/></td>
					<td><xsl:value-of select="format-number(@L,'#.##0,0','de')"/></td>
					<td><xsl:value-of select="format-number(key('ResultKey',@MUID)/@Flow_Max,'#.##0,00','de')"/></td>
					<td><xsl:value-of select="format-number(key('ResultKey',@MUID)/@Velocity_Max,'#.##0,00','de')"/></td>
					<td><xsl:value-of select="format-number(key('ResultKey',@MUID)/@Headloss1000_Max,'#.##0,00','de')"/></td>
				</tr>
			</xsl:for-each>
			</table>

			<!-- Some comment
			     In order to make custom text visible, remove: display:none -->
			<p style="font-size: 9pt; margin-top: 5px; display:none;">Comment</p>

		</body>
	</html>

</xsl:template>

<!-- Lookup table for unit abbreviations -->
<xsl:template name="ChooseUnitAbbr">
	<xsl:param name="UnitString"/>
	<xsl:choose>
		<!-- Length -->
		<xsl:when test="$UnitString = 'CentiMeter'"><xsl:text>[cm]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Feet'"><xsl:text>[ft]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Inch'"><xsl:text>[in]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'KiloMeter'"><xsl:text>[km]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Meter'"><xsl:text>[m]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Mile'"><xsl:text>[mi]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliFeet'"><xsl:text>[mft]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliMeter'"><xsl:text>[mm]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Yard'"><xsl:text>[yd]</xsl:text></xsl:when>
		<!--  Pressure -->
		<xsl:when test="$UnitString = 'Bar'"><xsl:text>[bar]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'FeetOfWater'"><xsl:text>[ft]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'HectoPascal'"><xsl:text>[hPa]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'KiloNewtonPerSquareMeter'"><xsl:text>[kN/m2]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'KiloPascal'"><xsl:text>[kPa]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MegaPascal'"><xsl:text>[MPa]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MetresOfWater'"><xsl:text>[m]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'NewtonPerSquareMeter'"><xsl:text>[N/m2]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Pascal'"><xsl:text>[Pa]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Psi'"><xsl:text>[psi]</xsl:text></xsl:when>
		<!--  Flow -->
		<xsl:when test="$UnitString = 'AcreFeetPerDay'"><xsl:text>[AFD]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicFeetPerDay'"><xsl:text>[ft^3/d]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicFeetPerHour'"><xsl:text>[ft^3/h]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicFeetPerMinute'"><xsl:text>[ft^3/min]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicFeetPerSecond'"><xsl:text>[ft^3/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicFeetPerYear'"><xsl:text>[ft^3/yr]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicMeterPerDay'"><xsl:text>[m3/d]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicMeterPerHour'"><xsl:text>[m3/h]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicMeterPerMinute'"><xsl:text>[m3/min]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicMeterPerSecond'"><xsl:text>[m3/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CubicMeterPerYear'"><xsl:text>[m3/yr]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'GallonPerDay'"><xsl:text>[gal/d]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'GallonPerMinute'"><xsl:text>[GPM]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'GallonPerSecond'"><xsl:text>[gal/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'GallonPerYear'"><xsl:text>[gal/yr]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'LiterPerDay'"><xsl:text>[l/d]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'LiterPerMinute'"><xsl:text>[l/min]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'LiterPerSecond'"><xsl:text>[l/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MillionGallonPerDay'"><xsl:text>[MGD]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MillionLiterPerDay'"><xsl:text>[MLD]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MillionUKGallonPerDay'"><xsl:text>[IMGD]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'UKGallonPerSecond'"><xsl:text>[Igal/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'UKGallonPerYear'"><xsl:text>[Igal/yr]</xsl:text></xsl:when>
		<!--  Velocity -->		
		<xsl:when test="$UnitString = 'CentiMeterPerHour'"><xsl:text>[cm/h]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'CentiMeterPerSecond'"><xsl:text>[cm/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'FeetPerDay'"><xsl:text>[ft/d]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'FeetPerHour'"><xsl:text>[ft/h]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'FeetPerMinute'"><xsl:text>[ft/min]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'FeetPerSecond'"><xsl:text>[ft/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'InchPerDay'"><xsl:text>[in/d]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'InchPerHour'"><xsl:text>[in/h]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'InchPerMinute'"><xsl:text>[in/min]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'InchPerSecond'"><xsl:text>[in/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'KiloMeterPerHour'"><xsl:text>[km/h]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Knot'"><xsl:text>[knot]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MeterPerDay'"><xsl:text>[m/d]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MeterPerHour'"><xsl:text>[m/h]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MeterPerMinute'"><xsl:text>[m/min]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MeterPerSecond'"><xsl:text>[m/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MicroMeterPerSecond'"><xsl:text>[mu-m/s]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilePerHour'"><xsl:text>[mi/h]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliMeterPerDay'"><xsl:text>[mm/d]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliMeterPerHour'"><xsl:text>[mm/h]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliMeterPerMonth'"><xsl:text>[mm/month]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliMeterPerSecond'"><xsl:text>[mm/s]</xsl:text></xsl:when>
		<!-- otherwise -->
		<xsl:otherwise><xsl:text>[?]</xsl:text></xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
